fedex.services.ship_service

Package fedex :: Package services :: Module ship_service |
[hide private]
[frames] | no frames]

# Module ship_service

source code

# Ship Service Module

This package contains the shipping methods defined by Fedex's ShipService WSDL file. Each is encapsulated in a class for easy access. For more details on each, refer to the respective class's documentation.

Classes | [hide private]
| FedexProcessShipmentRequest This class allows you to process (create) a new FedEx shipment.
| FedexDeleteShipmentRequest This class allows you to delete a shipment, given a tracking number.

Variables | [hide private]
| __package__ = ``'``fedex.services``'``